@@ -9,7 +9,7 @@ class NullHandler(logging.Handler):
 logging.getLogger('cassandra').addHandler(NullHandler())
 
 
-__version_info__ = (1, 0, '0')
+__version_info__ = (1, 0, 1)
 __version__ = '.'.join(map(str, __version_info__))
 
 
@@ -226,4 +226,19 @@ class OperationTimedOut(Exception):
     to complete.  This is not an error generated by Cassandra, only
     the driver.
     """
-    pass
+
+    errors = None
+    """
+    A dict of errors keyed by the :class:`~.Host` against which they occurred.
+    """
+
+    last_host = None
+    """
+    The last :class:`~.Host` this operation was attempted against.
+    """
+
+    def __init__(self, errors=None, last_host=None):
+        self.errors = errors
+        self.last_host = last_host
+        message = "errors=%s, last_host=%s" % (self.errors, self.last_host)
+        Exception.__init__(self, message)
