@@ -1,4 +1,4 @@
-from bisect import bisect_left
+from bisect import bisect_right
 from collections import defaultdict
 try:
     from collections import OrderedDict
@@ -561,7 +561,7 @@ class KeyspaceMetadata(object):
         self.tables = {}
 
     def export_as_string(self):
-        return "\n".join([self.as_cql_query()] + [t.as_cql_query() for t in self.tables.values()])
+        return "\n".join([self.as_cql_query()] + [t.export_as_string() for t in self.tables.values()])
 
     def as_cql_query(self):
         ret = "CREATE KEYSPACE %s WITH REPLICATION = %s " % \
@@ -890,10 +890,11 @@ class TokenMap(object):
             if tokens_to_hosts is None:
                 return []
 
-        point = bisect_left(self.ring, token)
-        if point == 0 and token != self.ring[0]:
-            return tokens_to_hosts[self.ring[-1]]
-        elif point == len(self.ring):
+        # token range ownership is exclusive on the LHS (the start token), so
+        # we use bisect_right, which, in the case of a tie/exact match,
+        # picks an insertion point to the right of the existing match
+        point = bisect_right(self.ring, token)
+        if point == len(self.ring):
             return tokens_to_hosts[self.ring[0]]
         else:
             return tokens_to_hosts[self.ring[point]]
@@ -924,7 +925,7 @@ class Token(object):
         return self.value == other.value
 
     def __hash__(self):
-        return self.value
+        return hash(self.value)
 
     def __repr__(self):
         return "<%s: %r>" % (self.__class__.__name__, self.value)
